<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

require_once('Calendar/Month/Weekdays.php');

/**
 *  指定されたキーのパラメータ情報を取得
 *
 *  @access public
 *  @param  string  $key                キー
 */
function pocket_getParameter($key)
{
    if (isset($_GET[$key])) {
        return $_GET[$key];
    } elseif (isset($_POST[$key])) {
        return $_POST[$key];
    } elseif (isset($_REQUEST[$key])) {
        return $_REQUEST[$key];
    } elseif (isset($_COOKIE[$key])) {
        return $_COOKIE[$key];
    } elseif (isset($_SESSION[$key])) {
        return $_SESSION[$key];
    } else {
        return '';
    }
}

/**
 *  パラメータ情報を取得
 *
 *  @access public
 */
function pocket_getParameters()
{
    $params = array();
    $params = array_merge($params, $_SESSION);
    $params = array_merge($params, $_COOKIE);
    $params = array_merge($params, $_REQUEST);
    $params = array_merge($params, $_POST);
    $params = array_merge($params, $_GET);
    return $params;
}

/**
 *  Cookieに値を保存
 *
 *  @access public
 *  @param  string  $key                キー
 *  @param  string  $value              値
 */
function pocket_setCookie($key, $value)
{
    if ($key)
    {
        setcookie ($key, $value, time() + 60 * 60 * 24 * 30);
    }
}

/**
 *  文字列のクォート部分を再帰的に取り除く
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_stripSlashes($data)
{
    return is_array($data) ?
                array_map('pocket_stripSlashes', $data) :
                stripslashes($data);
}

/**
 *  文字列をCSV用に加工する
 *
 *  @access public
 *  @param  string  $value              対象文字列
 *  @param  string  $quotation          クォーテーション付加フラグ
 */
function pocket_shape4csv($value, $quotation = true)
{
    $value = str_replace('"', "", $value);
    $value = str_replace("\n", "", $value);
    $value = str_replace("\r", "", $value);
    if ($quotation)
    {
        $value = '"' . $value . '"';
    }
    return $value;
}

/**
 *  ファイル名称をURLエンコードする
 *
 *  @access public
 *  @param  string  $file_name          ファイル名称
 */
function pocket_urlencode4file_name($file_name)
{
    $ua = $_SERVER['HTTP_USER_AGENT'];

    // ブラウザの判定
    if (strstr($ua, 'MSIE') && !strstr($ua, 'Opera'))
    {
        // IE
        $file_name = rawurlencode($file_name);
    }
    else
    {
        // IE以外
        $file_name = $file_name;
    }

    return $file_name;
}

/**
 *  SSL通信か判定
 *
 *  @access public
 */
function pocket_isSSL()
{
    if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on')
    {
        $is_ssl = true;
    } else {
        $is_ssl = false;
    }
}

/**
 *  サイトのURLを取得
 *
 *  @access public
 */
function pocket_getSiteUrl()
{
    // SSL通信か判定
    if (pocket_isSSL())
    {
        $location = 'https://';
    }
    else {
        $location = 'http://';
    }
    // HOST名（サーバに振り分けられているIPアドレス）
    $location .= $_SERVER['HTTP_HOST'];
    // エイリアス名
    $location .= POCKET_APL_ALIAS;

    return $location;
}

/**
 *  指定アクション画面にリダイレクト
 *
 *  @access public
 *  @param  string  $actName            アクション名
 *  @param  array   $params             パラメータ配列
 */
function pocket_redirect($actName, $params = array())
{
    // パラメータを付加
    if ($GLOBALS['_POCKET_MODULE'] == 'mobile' && session_id())
    {
        $params[session_name()] = session_id();
    }

    // サイトのURLを取得
    $location = pocket_getSiteUrl();
    // モジュール名
    $location .= '?m=' . $GLOBALS['_POCKET_MODULE'];
    // アクション名
    $location .= '&a=' . $actName;

    // 出力文字コード設定
    $output_charset = 'UTF-8';
    if ($GLOBALS['_POCKET_MODULE'] == 'mobile')
    {
        $output_charset = 'SJIS';
    }

    // パラメータ
    foreach($params as $key => $value)
    {
        $location .= '&' . $key . '=' . rawurlencode(mb_convert_encoding($value, $output_charset, 'UTF-8'));
    }

    // HTTPヘッダの送信
    header('Content-Type: text/html; charset=' . $output_charset);
    header('Location: ' . $location);
    exit;
}

/**
 *  エラー画面を表示
 *
 *  @access public
 *  @param  array   $errors             エラー情報配列
 *  @param  boolean $notfound           NOTFOUNDエラーフラグ
 */
function pocket_dispError($errors = array(), $notfound = false)
{
    // セッション情報の破棄
    $_SESSION = array();
    // セッションの破棄
    session_start();
    session_destroy();

    $smarty = new Pocket_Smarty();
    $smarty->template_dir = POCKET_MODULES_DIR . $GLOBALS['_POCKET_MODULE'] . '/templates';
    if ($GLOBALS['_POCKET_MODULE'] == 'mobile')
    {
        $smarty->output_charset = 'SJIS';
    }
    $smarty->assign('page_title', 'エラー');
    $smarty->assign('errors', (array)$errors);
    $smarty->assign('notfound', $notfound);
    // HTTPヘッダの送信
    header('Content-Type: text/html; charset=' . $smarty->output_charset);
    // テンプレートの表示
    $smarty->display('error.tpl');
    exit;
}

/**
 *  ファイルを一括読込み
 *
 *  @access public
 *  @param  string  $dir                ディレクトリ名称
 *  @param  string  $ext                拡張子
 */
function pocket_includeFiles($dir, $ext = '.php')
{
    if (is_dir($dir)) {
        if ($dh = opendir($dir)) {
            while (($file = readdir($dh)) !== false) {
                $path = realpath("$dir/$file");
                if ($file != '.' && $file != '..' && is_dir($path)) {
                    pocket_includeFiles($path);
                }
                if (substr($file, -4, 4) != $ext) continue;
                include_once $path;
            }
            closedir($dh);
        }
    }
}

/**
 *  カレンダーリストを生成
 *
 *  @access public
 *  @param  integer $year               年
 *  @param  integer $month              月
 *  @param  array   $day_list           アクティブ日付配列
 */
function pocket_getCalendarList($year, $month, $day_list = array())
{
    $calendar = new Calendar_Month_Weekdays($year, $month, 0);
    $calendar->build();

    $week = 0;
    while ($day = $calendar->fetch())
    {
        $day_info = array();
        if ($day->isFirst()) {$week++;}
        $day_info['day'] = $day->isEmpty() ? '' : $day->thisDay();
        $day_info['is_today'] = $day->isEmpty() ? false : pocket_isToday($year, $month, $day->thisDay());
        $day_info['is_active'] = in_array($day->thisDay(), $day_list);
        $calendar_list[$week][$day->thisDay()] = $day_info;
    }

    return $calendar_list;
}

/**
 *  今日の日付か判定
 *
 *  @access public
 *  @param  integer $year               年
 *  @param  integer $month              月
 *  @param  integer $day                日
 */
function pocket_isToday($year, $month, $day)
{
    if ($year == date('Y') && $month == date('m') && $day == date('d'))
    {
        return true;
    }

    return false;
}

/**
 *  年月差を算出し月数を返却
 *
 *  @access public
 *  @param  string  $f_year             開始年月(年)
 *  @param  string  $f_month            開始年月(月)
 *  @param  string  $t_year             終了年月(年)
 *  @param  string  $t_month            終了年月(月)
 */
function pocket_calcMonths4from_to($f_year, $f_month, $t_year, $t_month)
{
    $f_date = mktime(0, 0, 0, $f_month, 1, $f_year);
    $t_date = mktime(0, 0, 0, $t_month, 1, $t_year);
    return ceil(($t_date - $f_date) / 60 / 60 / 24 / 31) + 1;
}

/**
 *  日付差を算出し日数を返却
 *
 *  @access public
 *  @param  string  $f_year             開始日付(年)
 *  @param  string  $f_month            開始日付(月)
 *  @param  string  $f_day              開始日付(日)
 *  @param  string  $t_year             終了日付(年)
 *  @param  string  $t_month            終了日付(月)
 *  @param  string  $t_day              終了日付(日)
 */
function pocket_calcDays4from_to($f_year, $f_month, $f_day, $t_year, $t_month, $t_day)
{
    $f_date = mktime(0, 0, 0, $f_month, $f_day, $f_year);
    $t_date = mktime(0, 0, 0, $t_month, $t_day, $t_year);
    return ceil(($t_date - $f_date) / 60 / 60 / 24) + 1;
}

/**
 *  時間差を算出し分数を返却
 *
 *  @access public
 *  @param  string  $f_hour             開始時刻(時)
 *  @param  string  $f_minute           開始時刻(分)
 *  @param  string  $t_hour             終了時刻(時)
 *  @param  string  $t_minute           終了時刻(分)
 */
function pocket_calcMinutes4from_to($f_hour, $f_minute, $t_hour, $t_minute)
{
    $today = getdate();
    $f_time = mktime($f_hour, $f_minute, 0, $today['mon'], $today['mday'], $today['year']);
    $t_time = mktime($t_hour, $t_minute, 0, $today['mon'], $today['mday'], $today['year']);
    return ceil(($t_time - $f_time) / 60) + 1;
}

/**
 *  分数を時間フォーマットに変換する
 *
 *  @access public
 *  @param  integer $minutes            分数
 */
function pocket_timeFormat4minutes($minutes)
{
    if (!is_numeric($minutes)) {
        return $minutes;
    }
    if (intval($minutes) < 0) {
        $minutes = abs($minutes);
        $sign = "-";
    }
    return sprintf("%s%d:%02d", $sign, $minutes / 60, $minutes % 60);
}

/**
 *  時刻の妥当性を検証
 *
 *  @access public
 *  @param  string  $hour               時
 *  @param  string  $minute             分
 *  @param  string  $max_hour           最大時刻
 */
function pocket_checktime($hour, $minute, $max_hour = 23)
{
    if ($hour == null && $minute == null)
        return true;

    if (($hour != null && $minute == null) || ($hour == null && $minute != null))
        return false;

    if (!is_numeric($hour) || !is_numeric($minute))
        return false;

    if (intval($hour) < 0 || intval($hour) > $max_hour || intval($minute) < 0 || intval($minute) > 60)
        return false;

    return true;
}

/**
 *  開始時刻と終了時刻の妥当性(大小)を検証
 *  （時刻が全てNULLか片方の時刻がNULLの場合は正）
 *
 *  @access public
 *  @param  string  $f_hour             開始時刻(時)
 *  @param  string  $f_minute           開始時刻(分)
 *  @param  string  $t_hour             終了時刻(時)
 *  @param  string  $t_minute           終了時刻(分)
 *  @param  boolean $same_error         同一値エラーフラグ
 */
function pocket_checktimes($f_hour, $f_minute, $t_hour, $t_minute, $same_error = true)
{
    if ($f_hour == null && $f_minute == null && $t_hour == null && $t_minute == null)
        return true;

    if ($f_hour == null && $f_minute == null && $t_hour != null && $t_minute != null)
        return true;

    if ($f_hour != null && $f_minute != null && $t_hour == null && $t_minute == null)
        return true;

    if ($f_hour == null || $f_minute == null || $t_hour == null || $t_minute == null)
        return false;

    $f_time = sprintf("1%02d%02d", $f_hour, $f_minute);
    $t_time = sprintf("1%02d%02d", $t_hour, $t_minute);

    if ($same_error)
    {
        return (intval($f_time) < intval($t_time));
    }
    else {
        return (intval($f_time) <= intval($t_time));
    }
}

/**
 *  カウンタ表示用配列を生成
 *
 *  @access public
 *  @param  integer $count              カウント数
 *  @param  integer $digit              桁数
 */
function pocket_getCountAssoc($count, $digit)
{
    $assoc = array();
    $count = sprintf('%0' . $digit . 'd', $count);
    for ($i = 0; $i < strlen($count); $i++)
    {
        $assoc[$i]['num'] = substr($count, $i, 1);
    }
    return $assoc;
}

/**
 *  連想配列を生成
 *
 *  @access public
 *  @param  integer $from               開始番号
 *  @param  integer $to                 終了番号
 *  @param  integer $step               ステップ数
 */
function pocket_getAssoc4int($from, $to, $step = 1)
{
    $from = intval($from);
    $to = intval($to);
    if ($from > $to) return array();

    for ($i = $from; $i <= $to;) {
        $assoc[$i] = $i;
        $i += $step;
    }
    return $assoc;
}

/**
 *  月の連想配列を生成
 *
 *  @access public
 */
function pocket_getAssoc4month()
{
    return pocket_getAssoc4int(1, 12);
}

/**
 *  日の連想配列を生成
 *
 *  @access public
 */
function pocket_getAssoc4day()
{
    return pocket_getAssoc4int(1, 31);
}

/**
 *  時の連想配列を生成
 *
 *  @access public
 */
function pocket_getAssoc4hour()
{
    return pocket_getAssoc4int(0, 23);
}

/**
 *  分の連想配列を生成
 *
 *  @access public
 *  @param  integer $step               ステップ数
 */
function pocket_getAssoc4minutes($step = 1)
{
    return pocket_getAssoc4int(0, 59, $step);
}

/**
 *  曜日の連想配列を生成
 *
 *  @access public
 */
function pocket_getAssoc4week()
{
    return array("日", "月", "火", "水", "木", "金", "土");
}

/**
 *  日本語の曜日名を取得
 *
 *  @access public
 *  @param  integer $week               曜日番号
 */
function pocket_getWeekdayNameJP($week)
{
    $weekday = pocket_getAssoc4week();
    return $weekday[$week];
}

?>
